'use strict';

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

var FormErrors = require('./FormErrors');
var RequestDataContainer = require('./RequestDataContainer');

/**
* this class handles everything that concerns
* about forms. Submit and errors and considered too
*/

var Form = function () {

  /**
   * Set up the form class setting the data properties
   * directly to the form properties
   *
   * @param  {Object}  data
   * @param  {Boolean} clearAfterResponse
   * @return {void}
   */
  function Form(data) {
    var method = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 'post';
    var clearAfterResponse = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : false;

    _classCallCheck(this, Form);

    this.originalData = data;
    Object.assign(this, JSON.parse(JSON.stringify(data)));
    this.method = method;
    this.clearAfterResponse = clearAfterResponse;
    this.errors = new FormErrors();

    if (window.axios == undefined) {
      this.axios = require('axios');
    } else {
      this.axios = window.axios;
    }
  }

  _createClass(Form, [{
    key: 'reset',


    /**
     * Reset the form data
     *
     * @return {void}
     */
    value: function reset() {
      Object.assign(this, JSON.parse(JSON.stringify(this.originalData)));
      this.errors.clear();
    }

    /**
     * Return the form data
     *
     * @todo Add the option to choose between form data and plain object
     * @return {Object}
     */

  }, {
    key: 'data',
    value: function data(type) {
      var container = new RequestDataContainer(type);

      for (var field in this.originalData) {
        container.set(field, this[field]);
      }

      if (this.method != 'post') {
        container.set('_method', this.method);
      }

      return container.data;
    }

    /**
     * Set the form method.
     *
     * @param {String} method
     */

  }, {
    key: 'setMethod',
    value: function setMethod(method) {
      this.method = method;

      return this;
    }

    /**
     * Get the errors for a field.
     *
     * @param  {String} field
     * @return {String}
     */

  }, {
    key: 'errorsFor',
    value: function errorsFor(field) {
      return this.errors.get(field);
    }

    /**
     * Submit the form and return a promise
     *
     * @param  {string} url
     * @return {Promise}
     */

  }, {
    key: 'submit',
    value: function submit(url) {
      var _this = this;

      var dataType = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 'form-data';

      var supportedMethods = ['post', 'put', 'patch'];

      if (supportedMethods.indexOf(this.method.toLowerCase()) == -1) {
        throw new Error('Unssuported method');
      }

      return new Promise(function (resolve, reject) {
        _this.axios.post(url, _this.data(dataType)).then(function (response) {
          _this.formSubmitSucceded(response);
          resolve(response);
        }).catch(function (error) {
          _this.formSubmitFailed(error);
          reject(error);
        });
      });
    }

    /**
     * Perform actions after submition succeded
     *
     * @param  {Object} response
     * @return {void}
     */

  }, {
    key: 'formSubmitSucceded',
    value: function formSubmitSucceded(response) {
      if (this.clearAfterResponse) {
        this.reset();
      }
    }

    /**
     * Perform actions after submition failed
     *
     * @param  {Object} errors
     * @return {void}
     */

  }, {
    key: 'formSubmitFailed',
    value: function formSubmitFailed(errors) {
      if (errors.response.status == 422) {
        this.errors.record(errors.response.data.errors);
      }
    }
  }], [{
    key: 'makeFrom',
    value: function makeFrom(data) {
      var method = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 'post';
      var clearAfterResponse = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : false;

      return new this(data, method, clearAfterResponse);
    }
  }]);

  return Form;
}();

module.exports = Form;